@@ -1,7 +1,7 @@
 /*
  * DMNTK - Decision Model and Notation Toolkit
  *
- * DMNTK common definitions.
+ * Common definitions
  *
  * Copyright 2018-2021 Dariusz Depta Engos Software <dariusz.depta@engos.software>
  *
@@ -25,4 +25,7 @@ macro_rules! null_with_trace {
   ($l:expr) => {
     Value::Null(Some(format!("{}", $l)))
   };
+  () => {
+    Value::Null(None)
+  };
 }
